@@ -18,8 +18,6 @@ m2  <- x$VC$m2
 m3  <- x$VC$m3 
 bin.link <- x$VC$bl  
 end <- 0
-epsilon <- sqrt(.Machine$double.eps)
-max.p   <- 0.9999999
 est.ATb <- NA
 indD <- list()
 
@@ -164,8 +162,8 @@ if(eq==2) ngam <- x$gam2
 # OR
 #############################################################################
 
-p.int1 <- probm(eti1, x$margins[eq])$pr 
-p.int0 <- probm(eti0, x$margins[eq])$pr 
+p.int1 <- probm(eti1, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+p.int0 <- probm(eti0, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
 
 est.AT <- ( mean(p.int1, na.rm = TRUE) * (1 - mean(p.int0, na.rm = TRUE)) ) / ( (1 - mean(p.int1, na.rm = TRUE))*mean(p.int0, na.rm = TRUE)  ) 
 
@@ -182,8 +180,8 @@ est.AT <- ( mean(p.int1, na.rm = TRUE) * (1 - mean(p.int0, na.rm = TRUE)) ) / (
                            eti0s <- d0%*%t(bs[,ind.int]) 
                            }  
 
- peti1s <- probm(eti1s, x$margins[eq])$pr 
- peti0s <- probm(eti0s, x$margins[eq])$pr 
+ peti1s <- probm(eti1s, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
+ peti0s <- probm(eti0s, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr 
 
  est.ATb <- ( colMeans(peti1s, na.rm = TRUE)*(1-colMeans(peti0s, na.rm = TRUE)) ) / ( (1-colMeans(peti1s, na.rm = TRUE))*colMeans(peti0s, na.rm = TRUE) )    
 
@@ -260,9 +258,9 @@ lpm    <- as.matrix( predict.gam(x$gam1, newdata = data, type = "lpmatrix") )
 eta1   <- lpm%*%coefe
 etins  <- lpm%*%coefes
 
-fy1.y2[[i]]   <- mean(probm(eta1, x$margins[eq])$pr )
+fy1.y2[[i]]   <- mean(probm(eta1, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr )
 fy10.y2[[i]]  <- 1 - fy1.y2[[i]]
-fy1.y2S[[i]]  <- colMeans( probm(etins, x$margins[eq])$pr  )
+fy1.y2S[[i]]  <- colMeans( probm(etins, x$margins[eq], min.dn = x$VC$min.dn, min.pr = x$VC$min.pr, max.pr = x$VC$max.pr)$pr  )
 fy10.y2S[[i]] <- 1 - fy1.y2S[[i]]
 
 
