@@ -1,15 +1,13 @@
 bprobgHstwoParC <- function(params, respvec, VC, ps, AT = FALSE){
+p1 <- p2 <- pdf1 <- pdf2 <- c.copula.be2 <- c.copula.be1 <- c.copula2.be1be2 <- NA
 
- 
-  epsilon <- sqrt(.Machine$double.eps)
-  max.p   <- 0.9999999
 
   eta1 <- VC$X1%*%params[1:VC$X1.d2]
   eta2 <- VC$X2%*%params[(VC$X1.d2+1):(VC$X1.d2+VC$X2.d2)]
   nu <- etad <- etas1 <- etas2 <- etan <- etan1 <- etan2 <- NULL  
   
-  pd1 <- probm(eta1, VC$margins[1], only.pr = FALSE)
-  pd2 <- probm(eta2, VC$margins[2], only.pr = FALSE)
+  pd1 <- probm(eta1, VC$margins[1], only.pr = FALSE, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
+  pd2 <- probm(eta2, VC$margins[2], only.pr = FALSE, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
   
   p1 <- pd1$pr; d.n1 <- pd1$d.n 
   p2 <- pd2$pr; d.n2 <- pd2$d.n  
@@ -42,17 +40,25 @@ resT    <- teta.tr(VC, teta.st)
 teta.st <- resT$teta.st
 teta    <- resT$teta 
     
-p11 <- BiCDF(p1, p2, VC$nC, teta, nu)
+p11 <- mm(BiCDF(p1, p2, VC$nC, teta, nu), min.pr = VC$min.pr, max.pr = VC$max.pr  )
 
 ########################################################################################################
 
-  p10 <- pmax(p1 - p11, epsilon)
-  p01 <- pmax(p2 - p11, epsilon)
-  p00 <- pmax(1 - p11 - p10 - p01, epsilon)
+  p10 <- mm(p1 - p11, min.pr = VC$min.pr, max.pr = VC$max.pr)
+  p01 <- mm(p2 - p11, min.pr = VC$min.pr, max.pr = VC$max.pr)
+  p00 <- mm(1 - p11 - p10 - p01, min.pr = VC$min.pr, max.pr = VC$max.pr)
+  
+  
+    sall.p <- rowSums(cbind(p11, p10, p01, p00))
+    
+    p11 <- p11/sall.p 
+    p10 <- p10/sall.p
+    p01 <- p01/sall.p
+    p00 <- p00/sall.p
 
   l.par <- VC$weights*( respvec$y1.y2*log(p11) + respvec$y1.cy2*log(p10) + respvec$cy1.y2*log(p01) + respvec$cy1.cy2*log(p00) )
 
-dH <- copgHs(p1, p2, eta1=NULL, eta2=NULL, teta, teta.st, VC$BivD, nu, nu.st)
+dH <- copgHs(p1, p2, eta1=NULL, eta2=NULL, teta, teta.st, VC$BivD, nu, nu.st, min.dn = VC$min.dn, min.pr = VC$min.pr, max.pr = VC$max.pr)
 
 c.copula.be1   <- dH$c.copula.be1
 c.copula.be2   <- dH$c.copula.be2
@@ -460,7 +466,10 @@ if(VC$extra.regI == "sED") H <- regH(H, type = 2)
          list(value=res, gradient=G, hessian=H, S.h=S.h, S.h1=S.h1, S.h2=S.h2, l=S.res, l.par=l.par, ps = ps, 
               p11=p11, p10=p10, p01=p01, p00=p00, eta1=eta1, eta2=eta2, etad=etad, 
               dl.dbe1=dl.dbe1, dl.dbe2=dl.dbe2, dl.drho=dl.drho,
-              BivD=VC$BivD, p1=p1, p2=p2, theta.star = teta.st,
+              BivD=VC$BivD, p1 = p1, p2 = p2, pdf1 = d.n1, pdf2 = d.n2,          
+	      	                    c.copula.be2 = c.copula.be2,
+	      	                    c.copula.be1 = c.copula.be1,
+              c.copula2.be1be2 = c.copula2.be1be2, theta.star = teta.st,
               etan = etan, dl.dnu.st=dl.ddof)      
 
 }
