@@ -1,4 +1,4 @@
-jc.probs2 <- function(x, y1, y2, newdata, type, cond, intervals, n.sim, prob.lev, cont1par, cont2par, cont3par, bin.link, epsilon){
+jc.probs2 <- function(x, y1, y2, newdata, type, cond, intervals, n.sim, prob.lev, cont1par, cont2par, cont3par, bin.link, min.pr, max.pr){
 
 nu1 <- nu2 <- nu <- sigma2 <- 1
 CIp12 <- NULL
@@ -42,7 +42,7 @@ sigma2 <- esp.tr(predict.SemiParBIV(x, eq = 3, newdata = newdata), x$margins[2])
 if(x$margins[2] %in% cont2par) eq.th <- 4
 if(x$margins[2] %in% cont3par){ eq.nu <- 4; eq.th <- 5}
 
-if(x$margins[2] %in% cont3par) nu <- esp.tr(predict.SemiParBIV(x, eq = eq.nu, newdata = newdata), x$margins[2])$vrb
+if(x$margins[2] %in% cont3par) nu <- enu.tr(predict.SemiParBIV(x, eq = eq.nu, newdata = newdata), x$margins[2])$vrb
 
 theta <- teta.tr(x$VC, predict.SemiParBIV(x, eq = eq.th, newdata = newdata))$teta
 
@@ -87,9 +87,9 @@ if((cond == 0 && x$margins[2] %in% c(x$VC$m2, x$VC$m3)) || (cond == 1 && x$margi
 
 
 p0  <- 1 - p1         
-p2  <- distrHsAT(y2, eta2, sigma2, nu, x$margins[2])$p2
+p2  <- distrHsAT(y2, eta2, sigma2, nu, x$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2
 
-if(!(x$BivD %in% x$BivD2)) p12 <- BiCDF(p0, p2, x$nC, theta, dof)
+if(!(x$BivD %in% x$BivD2)) p12 <- mm(BiCDF(p0, p2, x$nC, theta, dof), min.pr = min.pr, max.pr = max.pr  )
 
 if(x$BivD %in% x$BivD2){
 
@@ -99,13 +99,13 @@ nC2 <- x$VC$ct[which(x$VC$ct[,1] == x$Cop2),2]
 p12 <- NA
 
 if( length(x$teta1) != 0){
-if(length(theta) > 1)  p12[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], p2[x$teta.ind1], nC1, theta[x$teta.ind1], dof)
-if(length(theta) == 1) p12[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], p2[x$teta.ind1], nC1, theta, dof)
+if(length(theta) > 1)  p12[x$teta.ind1] <- mm(BiCDF(p0[x$teta.ind1], p2[x$teta.ind1], nC1, theta[x$teta.ind1], dof), min.pr = min.pr, max.pr = max.pr  )
+if(length(theta) == 1) p12[x$teta.ind1] <- mm(BiCDF(p0[x$teta.ind1], p2[x$teta.ind1], nC1, theta, dof), min.pr = min.pr, max.pr = max.pr  )
                           }
                        
 if( length(x$teta2) != 0){
-if(length(theta) > 1)  p12[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], p2[x$teta.ind2], nC2, theta[x$teta.ind2], dof)
-if(length(theta) == 1) p12[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], p2[x$teta.ind2], nC2, theta, dof)
+if(length(theta) > 1)  p12[x$teta.ind2] <- mm(BiCDF(p0[x$teta.ind2], p2[x$teta.ind2], nC2, theta[x$teta.ind2], dof), min.pr = min.pr, max.pr = max.pr  )
+if(length(theta) == 1) p12[x$teta.ind2] <- mm(BiCDF(p0[x$teta.ind2], p2[x$teta.ind2], nC2, theta, dof), min.pr = min.pr, max.pr = max.pr  )
                           }                       
 
 }
@@ -133,10 +133,10 @@ if(cond == 2 && x$margins[2] %in% c(x$VC$m2, x$VC$m3)){#*# bin - cont
 
 
 p0  <- 1 - p1         
-p2  <- distrHsAT(y2, eta2, sigma2, nu, x$margins[2])$p2
+p2  <- distrHsAT(y2, eta2, sigma2, nu, x$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2
 
 
-if(!(x$BivD %in% x$BivD2)) p12 <- copgHsCond(p0, p2, theta, dof = dof, x$BivD)$c.copula.be2
+if(!(x$BivD %in% x$BivD2)) p12 <- copgHsCond(p0, p2, theta, dof = dof, x$BivD, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
 
 
 if(x$BivD %in% x$BivD2){
@@ -144,13 +144,13 @@ if(x$BivD %in% x$BivD2){
 p12 <- NA
  
 if( length(x$teta1) != 0){
-if(length(theta) > 1)  p12[x$teta.ind1] <- copgHsCond(p0[x$teta.ind1], p2[x$teta.ind1], theta[x$teta.ind1], dof = dof, x$Cop1)$c.copula.be2
-if(length(theta) == 1) p12[x$teta.ind1] <- copgHsCond(p0[x$teta.ind1], p2[x$teta.ind1], theta, dof = dof, x$Cop1)$c.copula.be2
+if(length(theta) > 1)  p12[x$teta.ind1] <- copgHsCond(p0[x$teta.ind1], p2[x$teta.ind1], theta[x$teta.ind1], dof = dof, x$Cop1, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
+if(length(theta) == 1) p12[x$teta.ind1] <- copgHsCond(p0[x$teta.ind1], p2[x$teta.ind1], theta, dof = dof, x$Cop1, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
                          }  
                           
 if( length(x$teta2) != 0){
-if(length(theta) > 1)  p12[x$teta.ind2] <- copgHsCond(p0[x$teta.ind2], p2[x$teta.ind2], theta[x$teta.ind2], dof = dof, x$Cop2)$c.copula.be2
-if(length(theta) == 1) p12[x$teta.ind2] <- copgHsCond(p0[x$teta.ind2], p2[x$teta.ind2], theta, dof = dof, x$Cop2)$c.copula.be2
+if(length(theta) > 1)  p12[x$teta.ind2] <- copgHsCond(p0[x$teta.ind2], p2[x$teta.ind2], theta[x$teta.ind2], dof = dof, x$Cop2, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
+if(length(theta) == 1) p12[x$teta.ind2] <- copgHsCond(p0[x$teta.ind2], p2[x$teta.ind2], theta, dof = dof, x$Cop2, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
                          }                            
                                                                            
                        }
@@ -171,7 +171,7 @@ if(y1 == 1) p12  <- 1 - p12 ### y1=1 | y2=x ###
 if(x$margins[2] %in% c(x$VC$m2d, x$VC$m1d)){#*# bin - discr
 
 p0   <- 1 - p1
-ppdf <- distrHsATDiscr(y2, eta2, sigma2, nu = 1, x$margins[2], x$VC$y2m)
+ppdf <- distrHsATDiscr(y2, eta2, sigma2, nu = 1, x$margins[2], x$VC$y2m, min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)
 p2   <- ppdf$p2 
 pdf2 <- ppdf$pdf2
 
@@ -186,13 +186,13 @@ C1 <- C2 <- NA
 if( length(x$teta1) != 0){
 
 if(length(theta) > 1){
-C1[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], p2[x$teta.ind1],          nC1, theta[x$teta.ind1], dof)
-C2[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], mm(p2[x$teta.ind1]-pdf2[x$teta.ind1]), nC1, theta[x$teta.ind1], dof)
+C1[x$teta.ind1] <- mm(BiCDF(p0[x$teta.ind1], p2[x$teta.ind1],          nC1, theta[x$teta.ind1], dof), min.pr = min.pr, max.pr = max.pr  )
+C2[x$teta.ind1] <- mm(BiCDF(p0[x$teta.ind1], mm(p2[x$teta.ind1]-pdf2[x$teta.ind1], min.pr, max.pr), nC1, theta[x$teta.ind1], dof), min.pr = min.pr, max.pr = max.pr  )
                      }
 
 if(length(theta) == 1){
-C1[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], p2[x$teta.ind1],          nC1, theta, dof)
-C2[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], mm(p2[x$teta.ind1]-pdf2[x$teta.ind1]), nC1, theta, dof)
+C1[x$teta.ind1] <- mm(BiCDF(p0[x$teta.ind1], p2[x$teta.ind1],          nC1, theta, dof), min.pr = min.pr, max.pr = max.pr  )
+C2[x$teta.ind1] <- mm(BiCDF(p0[x$teta.ind1], mm(p2[x$teta.ind1]-pdf2[x$teta.ind1], min.pr, max.pr), nC1, theta, dof), min.pr = min.pr, max.pr = max.pr  )
                        }
 
                           }
@@ -202,13 +202,13 @@ C2[x$teta.ind1] <- BiCDF(p0[x$teta.ind1], mm(p2[x$teta.ind1]-pdf2[x$teta.ind1]),
 if( length(x$teta2) != 0){
 
 if(length(theta) > 1){
-C1[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], p2[x$teta.ind2],          nC2, theta[x$teta.ind2], dof)
-C2[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], mm(p2[x$teta.ind2]-pdf2[x$teta.ind2]), nC2, theta[x$teta.ind2], dof)
+C1[x$teta.ind2] <- mm(BiCDF(p0[x$teta.ind2], p2[x$teta.ind2],          nC2, theta[x$teta.ind2], dof), min.pr = min.pr, max.pr = max.pr  )
+C2[x$teta.ind2] <- mm(BiCDF(p0[x$teta.ind2], mm(p2[x$teta.ind2]-pdf2[x$teta.ind2], min.pr, max.pr), nC2, theta[x$teta.ind2], dof), min.pr = min.pr, max.pr = max.pr  )
                      }
 
 if(length(theta) == 1){
-C1[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], p2[x$teta.ind2],          nC2, theta, dof)
-C2[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], mm(p2[x$teta.ind2]-pdf2[x$teta.ind2]), nC2, theta, dof)
+C1[x$teta.ind2] <- mm(BiCDF(p0[x$teta.ind2], p2[x$teta.ind2],          nC2, theta, dof), min.pr = min.pr, max.pr = max.pr  )
+C2[x$teta.ind2] <- mm(BiCDF(p0[x$teta.ind2], mm(p2[x$teta.ind2]-pdf2[x$teta.ind2], min.pr, max.pr), nC2, theta, dof), min.pr = min.pr, max.pr = max.pr  )
                        }
 
                           }                       
@@ -219,14 +219,14 @@ C2[x$teta.ind2] <- BiCDF(p0[x$teta.ind2], mm(p2[x$teta.ind2]-pdf2[x$teta.ind2]),
 
 if(!(x$BivD %in% x$BivD2)){
 
-C1 <- BiCDF(p0, p2,          x$nC, theta, dof)
-C2 <- BiCDF(p0, mm(p2-pdf2), x$nC, theta, dof)
+C1 <- mm(BiCDF(p0, p2,          x$nC, theta, dof), min.pr = min.pr, max.pr = max.pr  )
+C2 <- mm(BiCDF(p0, mm(p2-pdf2, min.pr, max.pr), x$nC, theta, dof), min.pr = min.pr, max.pr = max.pr  )
 
 }
 
 
 
-A <- ifelse(C1 - C2 < epsilon, epsilon, C1 - C2)
+A <- ifelse(C1 - C2 < min.pr, min.pr, C1 - C2)
 
 if(y1 == 0){
 
@@ -238,7 +238,7 @@ if(cond == 2) p12 <- p12/pdf2
 
 if(y1 == 1){
 
-p12 <- ifelse( pdf2 - A < epsilon, epsilon, pdf2 - A)
+p12 <- ifelse( pdf2 - A < min.pr, min.pr, pdf2 - A)
 if(cond == 1) p12 <- p12/p1
 if(cond == 2) p12 <- p12/pdf2
 
@@ -299,7 +299,7 @@ if( missing(newdata)){ X1 <- x$X1
                        }  
 
 
-p1s   <- probm( X1%*%t(bs[,1:x$X1.d2]), x$VC$margins[1])$pr 
+p1s   <- probm( X1%*%t(bs[,1:x$X1.d2]), x$VC$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pr 
 eta2s <- eta.tr( X2s%*%t(bs[,(x$X1.d2+1):(x$X1.d2+x$X2.d2)]) , x$VC$margins[2])
 
 #############  
@@ -400,7 +400,7 @@ if( missing(newdata)){ if(x$VC$ccss == "yes") X4s <- x$X4s else X4s <- x$X4}
   
                       }
   
- nu <- esp.tr(nu.st, x$VC$margins[2])$vrb   
+ nu <- enu.tr(nu.st, x$VC$margins[2])$vrb   
   
 } 
 
@@ -422,21 +422,21 @@ nu       <- matrix(rep(nu, each = dim(eta2s)[1]), ncol = n.sim, byrow=FALSE)
 if((cond == 0 && x$margins[2] %in% c(x$VC$m2, x$VC$m3)) || (cond == 1 && x$margins[2] %in% c(x$VC$m2, x$VC$m3))){#*#
 
 p0s  <- matrix(1 - p1s, dim(p1s)[1], n.sim)         
-p2s  <- matrix( distrHsAT(y2, eta2s, sigma2, nu, x$margins[2])$p2 , dim(p1s)[1], n.sim)
+p2s  <- matrix( distrHsAT(y2, eta2s, sigma2, nu, x$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2 , dim(p1s)[1], n.sim)
 
-if(x$VC$BivD %in% c("N","T")) p12s <- matrix(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), dim(p1s)[1], n.sim) else{
+if(x$VC$BivD %in% c("N","T")) p12s <- matrix(mm(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim) else{
 
 
 if(x$BivD %in% x$BivD2){
 
 p12s <- matrix(NA, ncol = n.sim, nrow = dim(p0s)[1])
 
-if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- BiCDF(p0s[x$teta.ind1,], p2s[x$teta.ind1,], nC1,  est.RHOb[x$teta.ind1,])                  
-if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- BiCDF(p0s[x$teta.ind2,], p2s[x$teta.ind2,], nC2, -est.RHOb[x$teta.ind2,])
+if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- mm(BiCDF(p0s[x$teta.ind1,], p2s[x$teta.ind1,], nC1,  est.RHOb[x$teta.ind1,]), min.pr = min.pr, max.pr = max.pr  )               
+if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- mm(BiCDF(p0s[x$teta.ind2,], p2s[x$teta.ind2,], nC2, -est.RHOb[x$teta.ind2,]), min.pr = min.pr, max.pr = max.pr  )
                       
                         }
 
-if(!(x$BivD %in% x$BivD2)) p12s <- matrix( BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE) , dim(p1s)[1], n.sim)
+if(!(x$BivD %in% x$BivD2)) p12s <- matrix( mm(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ) , dim(p1s)[1], n.sim)
 
 
 }
@@ -459,10 +459,10 @@ if(cond == 1) p12s <- p12s/p1s
 if(cond == 2 && x$margins[2] %in% c(x$VC$m2, x$VC$m3)){#*# bin - cont
 
 p0s  <- matrix( 1 - p1s , dim(p1s)[1], n.sim)        
-p2s  <- matrix( distrHsAT(y2, eta2s, sigma2, nu, x$margins[2])$p2, dim(p1s)[1], n.sim)
+p2s  <- matrix( distrHsAT(y2, eta2s, sigma2, nu, x$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2, dim(p1s)[1], n.sim)
 
 
-if(!(x$BivD %in% x$BivD2)) p12s <- matrix( copgHsCond(p0s, p2s, est.RHOb, dof = dof, x$BivD)$c.copula.be2, dim(p1s)[1], n.sim)
+if(!(x$BivD %in% x$BivD2)) p12s <- matrix( copgHsCond(p0s, p2s, est.RHOb, dof = dof, x$BivD, min.pr = min.pr, max.pr = max.pr)$c.copula.be2, dim(p1s)[1], n.sim)
          if(x$BivD == "T") p12s <- matrix(p12s, dim(p1s)[1], n.sim)
 
 
@@ -470,8 +470,8 @@ if(x$BivD %in% x$BivD2){
 
 p12s <- matrix(NA, ncol = n.sim, nrow = dim(p1s)[1])
  
-if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- copgHsCond(p0s[x$teta.ind1,], p2s[x$teta.ind1,],  est.RHOb[x$teta.ind1,], dof = dof, x$Cop1)$c.copula.be2                                               
-if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- copgHsCond(p0s[x$teta.ind2,], p2s[x$teta.ind2,], -est.RHOb[x$teta.ind2,], dof = dof, x$Cop2)$c.copula.be2
+if( length(x$teta1) != 0) p12s[x$teta.ind1,] <- copgHsCond(p0s[x$teta.ind1,], p2s[x$teta.ind1,],  est.RHOb[x$teta.ind1,], dof = dof, x$Cop1, min.pr = min.pr, max.pr = max.pr)$c.copula.be2                                               
+if( length(x$teta2) != 0) p12s[x$teta.ind2,] <- copgHsCond(p0s[x$teta.ind2,], p2s[x$teta.ind2,], -est.RHOb[x$teta.ind2,], dof = dof, x$Cop2, min.pr = min.pr, max.pr = max.pr)$c.copula.be2
                                                                                                      
                        }
 
@@ -490,23 +490,23 @@ if(y1 == 1) p12s <- 1 - p12s ### y1=1 | y2=x ###
 if(x$margins[2] %in% c(x$VC$m2d, x$VC$m1d)){#*#
 
 p0s   <- matrix( 1 - p1s , dim(p1s)[1], n.sim)
-ppdf  <- distrHsATDiscr(y2, eta2s, sigma2, nu = 1, x$margins[2], x$VC$y2m) # not sure about y2m
+ppdf  <- distrHsATDiscr(y2, eta2s, sigma2, nu = 1, x$margins[2], x$VC$y2m, min.dn = min.pr, min.pr = min.pr, max.pr = max.pr) # not sure about y2m
 p2s   <- matrix( ppdf$p2 ,  dim(p1s)[1], n.sim)
 pdf2s <- matrix( ppdf$pdf2, dim(p1s)[1], n.sim)
 
-if(x$VC$BivD %in% c("N","T")) C1s <- matrix(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), dim(p1s)[1], n.sim) else{
+if(x$VC$BivD %in% c("N","T")) C1s <- matrix(mm(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim) else{
 
 
 if(x$BivD %in% x$BivD2){
 
 C1s <- matrix(NA, ncol = n.sim, nrow = dim(p0s)[1])
 
-if( length(x$teta1) != 0) C1s[x$teta.ind1,] <- BiCDF(p0s[x$teta.ind1,], p2s[x$teta.ind1,], nC1,  est.RHOb[x$teta.ind1,])                  
-if( length(x$teta2) != 0) C1s[x$teta.ind2,] <- BiCDF(p0s[x$teta.ind2,], p2s[x$teta.ind2,], nC2, -est.RHOb[x$teta.ind2,])
+if( length(x$teta1) != 0) C1s[x$teta.ind1,] <- mm(BiCDF(p0s[x$teta.ind1,], p2s[x$teta.ind1,], nC1,  est.RHOb[x$teta.ind1,]), min.pr = min.pr, max.pr = max.pr  )                  
+if( length(x$teta2) != 0) C1s[x$teta.ind2,] <- mm(BiCDF(p0s[x$teta.ind2,], p2s[x$teta.ind2,], nC2, -est.RHOb[x$teta.ind2,]), min.pr = min.pr, max.pr = max.pr  )
                       
                         }
 
-if(!(x$BivD %in% x$BivD2)) C1s <- matrix(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), dim(p1s)[1], n.sim)
+if(!(x$BivD %in% x$BivD2)) C1s <- matrix(mm(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim)
 
 
 
@@ -514,19 +514,19 @@ if(!(x$BivD %in% x$BivD2)) C1s <- matrix(BiCDF(p0s, p2s, x$nC, est.RHOb, dof, te
 
 
 
-if(x$VC$BivD %in% c("N","T")) C2s <- matrix(BiCDF(p0s, mm(p2s-pdf2s), x$nC, est.RHOb, dof, test = FALSE), dim(p1s)[1], n.sim) else{
+if(x$VC$BivD %in% c("N","T")) C2s <- matrix(mm(BiCDF(p0s, mm(p2s-pdf2s, min.pr, max.pr), x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim) else{
 
 
 if(x$BivD %in% x$BivD2){
 
 C2s <- matrix(NA, ncol = n.sim, nrow = dim(p0s)[1])
 
-if( length(x$teta1) != 0) C2s[x$teta.ind1,] <- BiCDF(p0s[x$teta.ind1,], mm(p2s[x$teta.ind1,]-pdf2s[x$teta.ind1,]), nC1,  est.RHOb[x$teta.ind1,])                  
-if( length(x$teta2) != 0) C2s[x$teta.ind2,] <- BiCDF(p0s[x$teta.ind2,], mm(p2s[x$teta.ind2,]-pdf2s[x$teta.ind2,]), nC2, -est.RHOb[x$teta.ind2,])
+if( length(x$teta1) != 0) C2s[x$teta.ind1,] <- mm(BiCDF(p0s[x$teta.ind1,], mm(p2s[x$teta.ind1,]-pdf2s[x$teta.ind1,], min.pr, max.pr), nC1,  est.RHOb[x$teta.ind1,]) , min.pr = min.pr, max.pr = max.pr  )                 
+if( length(x$teta2) != 0) C2s[x$teta.ind2,] <- mm(BiCDF(p0s[x$teta.ind2,], mm(p2s[x$teta.ind2,]-pdf2s[x$teta.ind2,], min.pr, max.pr), nC2, -est.RHOb[x$teta.ind2,]), min.pr = min.pr, max.pr = max.pr  )
                       
                         }
 
-if(!(x$BivD %in% x$BivD2)) C2s <- matrix( BiCDF(p0s, mm(p2s-pdf2s), x$nC, est.RHOb, dof, test = FALSE), dim(p1s)[1], n.sim)
+if(!(x$BivD %in% x$BivD2)) C2s <- matrix( mm(BiCDF(p0s, mm(p2s-pdf2s, min.pr, max.pr), x$nC, est.RHOb, dof, test = FALSE), min.pr = min.pr, max.pr = max.pr  ), dim(p1s)[1], n.sim)
 
 
 }
@@ -534,7 +534,7 @@ if(!(x$BivD %in% x$BivD2)) C2s <- matrix( BiCDF(p0s, mm(p2s-pdf2s), x$nC, est.RH
 
 
 
-As <- ifelse(C1s - C2s < epsilon, epsilon, C1s - C2s)
+As <- ifelse(C1s - C2s < min.pr, min.pr, C1s - C2s)
 
 
 
@@ -546,7 +546,7 @@ if(cond == 2) p12s <- p12s/pdf2s
           }
 
 if(y1 == 1){
-p12s <- ifelse( pdf2s - As < epsilon, epsilon, pdf2s - As)
+p12s <- ifelse( pdf2s - As < min.pr, min.pr, pdf2s - As)
 if(cond == 1) p12s <- p12s/p1s
 if(cond == 2) p12s <- p12s/pdf2s
            }
@@ -625,7 +625,7 @@ if(type == "independence"){ # this will not work for ordinal
 if(!missing(newdata)){
 
 nu     <- sigma2 <- NA
-p1     <- probm(predict.SemiParBIV(x, eq = 1, newdata = newdata, type = "lpmatrix")%*%x$gam1$coefficients, x$VC$margins[1])$pr
+p1     <- probm(predict.SemiParBIV(x, eq = 1, newdata = newdata, type = "lpmatrix")%*%x$gam1$coefficients, x$VC$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pr
 eta2   <- predict.SemiParBIV(x, eq = 2, newdata = newdata, type = "lpmatrix")%*%x$gamlss$coefficients[1:x$X2.d2]
 
 
@@ -635,7 +635,7 @@ if( !(x$VC$margins[2] %in% cont1par) ){
 if( !is.null(x$X3) ){
 
 sigma2 <- esp.tr(predict.SemiParBIV(x, eq = 3, newdata = newdata, type = "lpmatrix")%*%x$gamlss$coefficients[(x$X2.d2+1):(x$X2.d2+x$X3.d2)], x$margins[2])$vrb
-if(x$margins[2] %in% cont3par) nu <- esp.tr(predict.SemiParBIV(x, eq = 4, newdata = newdata, type = "lpmatrix")%*%x$gamlss$coefficients[(x$X2.d2 + x$X3.d2 + 1):(x$X2.d2 + x$X3.d2 + x$X4.d2)], x$margins[2])$vrb
+if(x$margins[2] %in% cont3par) nu <- enu.tr(predict.SemiParBIV(x, eq = 4, newdata = newdata, type = "lpmatrix")%*%x$gamlss$coefficients[(x$X2.d2 + x$X3.d2 + 1):(x$X2.d2 + x$X3.d2 + x$X4.d2)], x$margins[2])$vrb
 
                     }
 
@@ -656,7 +656,7 @@ nu     <- x$gamlss$nu
 
 if(missing(newdata)){
 
-p1   <- probm(predict.SemiParBIV(x, eq = 1, type = "lpmatrix")%*%x$gam1$coefficients, x$VC$margins[1])$pr
+p1   <- probm(predict.SemiParBIV(x, eq = 1, type = "lpmatrix")%*%x$gam1$coefficients, x$VC$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pr
 eta2 <- x$gamlss$eta1
 
 sigma2 <- x$gamlss$sigma2
@@ -671,7 +671,7 @@ if(x$margins[2] %in% c(x$VC$m2, x$VC$m3)){#*#
 if(y1 == 0 || y1 == 1){  
 
 p0  <- 1 - p1                     
-p2  <- distrHsAT(y2, eta2, sigma2, nu, x$margins[2])$p2
+p2  <- distrHsAT(y2, eta2, sigma2, nu, x$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2
 p12 <- p0*p2
 
 if(cond == 1) p12 <- p2
@@ -700,7 +700,7 @@ if(cond == 2) p12 <- p1
 if(x$margins[2] %in% c(x$VC$m2d, x$VC$m1d)){#*#
 
 p0   <- 1 - p1
-pdf2 <- distrHsATDiscr(y2, eta2, sigma2, nu = 1, x$margins[2], x$VC$y2m)$pdf2  
+pdf2 <- distrHsATDiscr(y2, eta2, sigma2, nu = 1, x$margins[2], x$VC$y2m, min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pdf2  
 
 if(y1 == 0){
 p12 <- p0*pdf2
@@ -741,7 +741,7 @@ if( missing(newdata)){ X1 <- x$X1
                        if(x$VC$ccss == "yes") X2s <- x$X2s else X2s <- x$X2  
                        } 
   
-p1s   <- probm(   X1%*%t(bs1[,1:x$X1.d2]) , x$VC$margins[1])$pr   
+p1s   <- probm(   X1%*%t(bs1[,1:x$X1.d2]) , x$VC$margins[1], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pr   
 eta2s <- eta.tr( X2s%*%t(bs2[,1:x$X2.d2]) , x$VC$margins[2])
 
 #############  
@@ -781,7 +781,7 @@ if( missing(newdata)){ if(x$VC$ccss == "yes") X4s <- x$X4s else X4s <- x$X4}
              nu.st <- X4s%*%t(bs2[,(x$X2.d2 + x$X3.d2 + 1):(x$X2.d2 + x$X3.d2 + x$X4.d2)]) 
                       }
                       
- nu <- esp.tr(nu.st, x$VC$margins[2])$vrb   
+ nu <- enu.tr(nu.st, x$VC$margins[2])$vrb   
   
 } 
 
@@ -802,7 +802,7 @@ if(x$margins[2] %in% c(x$VC$m2, x$VC$m3)){#*#
 
 if(y1 == 0 || y1 == 1){                              
 p0s  <- matrix(1 - p1s, dim(p1s)[1], n.sim)                     
-p2s  <- matrix( distrHsAT(y2, eta2s, sigma2, nu, x$margins[2])$p2, dim(p1s)[1], n.sim)
+p2s  <- matrix( distrHsAT(y2, eta2s, sigma2, nu, x$margins[2], min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$p2, dim(p1s)[1], n.sim)
 p12s <- matrix( p0s*p2s, dim(p1s)[1], n.sim)
 
 if(cond == 1) p12s <- p2s
@@ -829,7 +829,7 @@ if(cond == 2) p12s <- p1s
 if(x$margins[2] %in% c(x$VC$m2d, x$VC$m1d)){#*#
 
 p0s   <- matrix( 1 - p1s, dim(p1s)[1], n.sim)
-pdf2s <- matrix( distrHsATDiscr(y2, eta2s, sigma2, nu = 1, x$margins[2], x$VC$y2m)$pdf2 , dim(p1s)[1], n.sim)         # not sure about y2m
+pdf2s <- matrix( distrHsATDiscr(y2, eta2s, sigma2, nu = 1, x$margins[2], x$VC$y2m, min.dn = min.pr, min.pr = min.pr, max.pr = max.pr)$pdf2 , dim(p1s)[1], n.sim)         # not sure about y2m
 
 if(y1 == 0){
 p12s <- p0s*pdf2s
